from musket_core import datasets,genericcsv,coders,image_datasets

@datasets.dataset_provider(origin="train.csv",kind="GenericDataSet")
def getTitanic():
    return genericcsv.GenericCSVDataSet("train.csv",["Sex","Fare","Age","Pclass"],["Survived"],[],
                                        {"Sex":"binary","Fare":"normalized_number","Age":"normalized_number","Pclass":"multi_class","Survived":"binary"},input_groups={"0":["Sex","Fare","Age","Pclass"]})
    
@datasets.dataset_provider(origin="saltExists.csv",kind="BinaryClassificationDataSet")
def getSe():
    return image_datasets.BinaryClassificationDataSet(["images"],"saltExists.csv","ImageId","Class")


@datasets.dataset_provider(origin="train.csv",kind="BinarySegmentationDataSet")
def getSaltTrain():
    return image_datasets.BinarySegmentationDataSet(["images","images"],"salt.csv","id","rle_mask")    


from setuptools import setup
import setuptools
setup(name='musket_ml',
      version='0.498',
      description='Common parts of my pipelines',
      url='https://github.com/petrochenko-pavel-a/musket_core',
      author='Petrochenko Pavel',
      author_email='petrochenko.pavel.a@gmail.com',
      license='MIT',
      packages=setuptools.find_packages(),
      include_package_data=True,
      install_requires=["musket_text>=0.442","musket_core>=0.497","classification_pipeline>=0.431","segmentation_pipeline>=0.431"],
      zip_safe=False)